@@ -19,7 +19,6 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 from dataclasses import dataclass
-from subprocess import PIPE
 from typing import List
 
 from psutil import Popen
@@ -34,7 +33,6 @@ class Model:
     username: str
     cpu_percent: float
     memory_percent: float
-    Popen: Popen
     
     @classmethod
     def from_process(cls, process: Popen) -> 'Model':
@@ -55,5 +53,4 @@ class Model:
             username=process.username(),
             cpu_percent=process.cpu_percent(),
             memory_percent=process.memory_percent(),
-            Popen=process
         )
